'use strict';

var _chai = require('chai');

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _okSelector = require('./ok-selector');

var _okSelector2 = _interopRequireDefault(_okSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('ok-selector', function () {
  context('native objects', function () {
    var state = {
      level1: {
        level2: {
          level3: {
            value: 'yes'
          }
        }
      },
      array: [{ id: 1, value: 2 }, { id: 2, value: 4 }, { id: 3, value: 6 }, { id: 4, value: 8 }]
    };

    it('should support dot.strings', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'level1.level2.level3.value')).to.equal('yes');
      (0, _chai.expect)((0, _okSelector2.default)(state, 'level1.level2.level3')).to.deep.equal({ value: 'yes' });
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array')).to.deep.equal([{ id: 1, value: 2 }, { id: 2, value: 4 }, { id: 3, value: 6 }, { id: 4, value: 8 }]);
    });

    it('should support addressing arrays by id', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array:3')).to.deep.equal({ id: 3, value: 6 });
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array:3.value')).to.deep.equal(6);
    });

    it('should support plucking all values from an array', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array*.value')).to.deep.equal([2, 4, 6, 8]);
    });
  });

  context('Immutable objects', function () {
    var state = _immutable2.default.fromJS({
      level1: {
        level2: {
          level3: {
            value: 'yes'
          }
        }
      },
      array: [{ id: 1, value: 2 }, { id: 2, value: 4 }, { id: 3, value: 6 }, { id: 4, value: 8 }]
    });

    it('should support dot.strings', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'level1.level2.level3.value')).to.equal('yes');
      (0, _chai.expect)((0, _okSelector2.default)(state, 'level1.level2.level3').toJS()).to.deep.equal({ value: 'yes' });
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array').toJS()).to.deep.equal([{ id: 1, value: 2 }, { id: 2, value: 4 }, { id: 3, value: 6 }, { id: 4, value: 8 }]);
    });

    it('should support addressing arrays by id', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array:3').toJS()).to.deep.equal({ id: 3, value: 6 });
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array:3.value')).to.deep.equal(6);
    });

    it('should support plucking all values from an array', function () {
      (0, _chai.expect)((0, _okSelector2.default)(state, 'array*.value').toJS()).to.deep.equal([2, 4, 6, 8]);
    });
  });
});